@@ -74,7 +74,9 @@ class ObjectValue(CfgValue):
             val_ = json.loads(str_val)
         except JSONDecodeError:
             try:
-                val_ = dict(hjson.loads(str_val))
+                # todo: hjson expects at most one none quoted 
+                # string on each line...
+                val_ = dict(hjson.loads(str_val.replace(",", "\n").replace("}", "\n}")))
             except Exception as e:
                 raise ValueError(f"Error parsing '{str_val}' with json or hjson. Got: {e}")
         return val_
@@ -164,6 +166,10 @@ class ObjectValue(CfgValue):
     @as_dict.setter
     def as_dict(self, val):
         self._value = val
+    
+    @property
+    def name(self):
+        return self._name
 
     def add(self, key, value, override=True):
         """
@@ -185,6 +191,9 @@ class ObjectValue(CfgValue):
     
     def __getitem__(self, key):
         return self._value[key]
+    
+    def __contains__(self, key):
+        return key in self._value
 
 
 
@@ -698,8 +707,11 @@ class OppConfigFileBase(MutableMapping):
     def values(self):
         return [v for _, v in self.__iter__()]
 
-    def get(self, k):
-        return self[k]
+    def get(self, k, default=None):
+        if k in self:
+            return self[k]
+        else:
+            return default
     
     def get_all(self, k, with_section: bool = True):
         ret = {}
